<div align="center">
  <img alt="calotron logo" src="https://raw.githubusercontent.com/mbarbetti/calotron/main/.github/images/calotron-logo.png" width="500"/>
</div>

<h3 align="center">
  <em>Transformer-based model to fast-simulate the LHCb ECAL detector</em>
</h3>

<p align="center">
  <a href="https://www.tensorflow.org/versions"><img alt="TensorFlow versions" src="https://img.shields.io/badge/tensorflow-2.10%20|%202.11-f57000?style=flat"></a>
  <a href="https://pypi.python.org/pypi/calotron"><img alt="PyPI - Python versions" src="https://img.shields.io/pypi/pyversions/calotron"></a>
  <a href="https://pypi.python.org/pypi/calotron"><img alt="PyPI - Version" src="https://img.shields.io/pypi/v/calotron"></a>
  <!--
  <a href="https://pypi.python.org/pypi/calotron"><img alt="PyPI - Status" src="https://img.shields.io/pypi/status/calotron"></a>
  <a href="https://pypi.python.org/pypi/calotron"><img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dm/calotron"></a>
  <a href="https://github.com/mbarbetti/calotron/issues"><img alt="GitHub - Issues" src="https://img.shields.io/github/issues/mbarbetti/calotron"></a>
  <a href="https://github.com/mbarbetti/calotron/pulls"><img alt="GitHub - Pull-requests" src="https://img.shields.io/github/issues-pr/mbarbetti/calotron"></a>
  <a href="https://github.com/mbarbetti/calotron/network/members"><img alt="GitHub - Forks" src="https://badgen.net/github/forks/mbarbetti/calotron"></a>
  <a href="https://github.com/mbarbetti/calotron/stargazers"><img alt="GitHub - Stars" src="https://img.shields.io/github/stars/mbarbetti/calotron"></a>
  -->
  <a href="https://github.com/mbarbetti/calotron/actions/workflows/style.yml"><img alt="GitHub - Style" src="https://github.com/mbarbetti/calotron/actions/workflows/style.yml/badge.svg?branch=main"></a>
  <a href="https://github.com/mbarbetti/calotron/actions/workflows/tests.yml"><img alt="GitHub - Tests" src="https://github.com/mbarbetti/calotron/actions/workflows/tests.yml/badge.svg?branch=main"></a>
  <a href="https://codecov.io/gh/mbarbetti/calotron"><img alt="Codecov" src="https://codecov.io/gh/mbarbetti/calotron/branch/main/graph/badge.svg?token=DRG8BWC9RR"></a>
</p>
